# Module: cdf_apm_simple_data_model

This module relies on cdf_oid_example_data being loaded to a RAW database.
The module creates a simple Asset Performance Management data model and
adds the necessary transformations to populate the model with data from the
Open Industrial Data data in cdf_oid_example_data.

It can be used standalone, but the transformations will then not be able to run without
modifications.
